@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c 6254 2008-04-20 16:24:26Z pborelli $
+ * $Id: gedit-window.c 6368 2008-08-09 13:37:59Z jessevdk $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 
 #include "gedit-ui.h"
 #include "gedit-window.h"
@@ -1232,7 +1232,7 @@ update_recent_files_menu (GeditWindow *window)
 
 		/* gtk_recent_info_get_uri_display (info) is buggy and
 		 * works only for local files */
-		uri = gedit_utils_format_uri_for_display (gtk_recent_info_get_uri (info));
+		uri = gedit_utils_uri_for_display (gtk_recent_info_get_uri (info));
 		ruri = gedit_utils_replace_home_dir_with_tilde (uri);
 		g_free (uri);
 
@@ -1380,7 +1380,7 @@ create_menu_bar_and_toolbar (GeditWindow *window,
 	window->priv->quit_action_group = action_group;
 
 	/* now load the UI definition */
-	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UI_DIR "gedit-ui.xml", &error);
+	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UIDIR "gedit-ui.xml", &error);
 	if (error != NULL)
 	{
 		g_warning ("Could not merge gedit-ui.xml: %s", error->message);
@@ -3617,45 +3617,63 @@ _gedit_window_set_saving_session_state (GeditWindow *window,
 }
 
 GeditTab *
-gedit_window_get_tab_from_uri (GeditWindow *window,
-			       const gchar *uri)
+gedit_window_get_tab_from_location (GeditWindow *window,
+				    GFile       *location)
 {
 	GList *tabs;
 	GList *l;
-	
+	GeditTab *ret = NULL;
+
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
-	g_return_val_if_fail (uri != NULL, NULL);
-	
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
+
 	tabs = gtk_container_get_children (GTK_CONTAINER (window->priv->notebook));
 	
-	l = tabs;
-	while (l != NULL)
+	for (l = tabs; l != NULL; l = g_list_next (l))
 	{
-		gchar *u;
 		GeditDocument *d;
 		GeditTab *t;
-		
+		GFile *f;
+
 		t = GEDIT_TAB (l->data);
 		d = gedit_tab_get_document (t);
 
-		u = gedit_document_get_uri (d);
+		f = gedit_document_get_location (d);
 
-		if ((u != NULL) && gnome_vfs_uris_match (uri, u))
+		if ((f != NULL))
 		{
-			g_free (u);
-			
-			g_list_free (tabs);
-			
-			return t;
+			gboolean found = g_file_equal (location, f);
+
+			g_object_unref (f);
+
+			if (found)
+			{
+				ret = t;
+				break;
+			}
 		}
-		
-		g_free (u);
-		
-		l = g_list_next (l);
 	}
 	
 	g_list_free (tabs);
 	
-	return NULL;
+	return ret;
+}
+
+/* for backward compat since it is public api */
+GeditTab *
+gedit_window_get_tab_from_uri (GeditWindow *window,
+			       const gchar *uri)
+{
+	GFile *f;
+	GeditTab *tab;
+
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	f = g_file_new_for_uri (uri);
+	tab = gedit_window_get_tab_from_location (window, f);
+	g_object_unref (f);
+
+	return tab;
 }
 
